@@ -19,11 +19,13 @@
 #ifndef LISTNODE_H
 #define LISTNODE_H
 
+#include "rocs_liststructure_export.h"
+
 #include <Data.h>
 #include <boost/shared_ptr.hpp>
 
 
-class ListNode : public Data
+class ROCS_LISTSTRUCTURE_EXPORT ListNode : public Data
 {
     Q_OBJECT
 public:
@@ -31,13 +33,15 @@ public:
     ListNode(DataStructurePtr parent, int uniqueIdentifier, int dataType);
     ~ListNode();
 
+    /**
+     * Return target of out-pointer if exactly one outgoing pointer exists, otherwise returns empty node.
+     * \return next node
+     */
     boost::shared_ptr<ListNode> next() const;
 
 public slots:
     QScriptValue front();
     void pointTo(boost::shared_ptr<ListNode> to);
-
-
 };
 
 #endif // LISTNODE_H
