@@ -218,121 +218,5 @@ void TestDataStructure::pointerTypesTest()
     QVERIFY(dataList[2]->adjacent_data().size() == 2);
     QVERIFY(dataList[6]->adjacent_data().size() == 0);
 }
-/*
-   void TestDataStructure::testKrossQtjs(){
-   //   createPentagon();
-   //
-   //   QVariantList graphLists;
-   //   graphLists.append( QVariant::fromValue( _graphDocument->at(0) ) );
-   //
-   //   KrossBackend *k = new KrossBackend(&graphLists);
-   //   k->setBackend("javascript");
-   //   k->loadFile("krossjstests.js");
-   //
-   //   Kross::Action *action = k->execute();
-   //   QVariant result;
-   //   result = action->callFunction("testGraphName");
-   //   QVERIFY2( result.toString() == "Graph1", "ERROR, Name of graph cannot be retrieved.");
-   //   result = action->callFunction("testGraphPropertyName");
-   //   QVERIFY2( result.toString() == "Graph1", "ERROR, Name of graph cannot be retrieved.");
-
-   }
-
-   void TestDataStructure::testKrossJs(){
-   createPentagon();
-
-   QVariantList graphLists;
-   graphLists.append( QVariant::fromValue( _graphDocument->at(0) ) );
-
-   KrossBackend *k = new KrossBackend(&graphLists);
-   k->setBackend("javascript");
-   k->loadFile("krossjstests.js");
-
-   Kross::Action *action = k->execute();
-   QVariant result;
-   //   result = action->callFunction("testGraphName");
-   // QVERIFY2( result.toString() == "Graph1", "ERROR, Name of graph cannot be retrieved.");
-   //   result = action->callFunction("testGraphPropertyName");
-   //  QVERIFY2( result.toString() == "Graph1", "ERROR, Name of graph cannot be retrieved.");
-        result = action->callFunction("testGraphNodeSize");
-        QVERIFY2( result.toString().toAscii()  == "5", "ERROR, size of graph is unknown");
-   }
-
-   void TestDataStructure::testKrossPy(){
-   createPentagon();
-
-   QVariantList graphLists;
-   graphLists.append( QVariant::fromValue( _graphDocument->at(0) ) );
-
-   KrossBackend *k = new KrossBackend(&graphLists);
-   k->setBackend("python");
-   k->loadFile("krosspytests.py");
-
-   Kross::Action *action = k->execute();
-   QVariant result;
-        //result = action->callFunction("testGraphPropertyName");
-        //QVERIFY2(result.toString().toAscii() == "Graph1", "ERROR: Name of the graph cannot be retrieved.");
-        result = action->callFunction("testNumberOfNodes");
-        QVERIFY2(result.toInt() == 5, "ERROR: Number of data cannot be retrieved.");
-        //result = action->callFunction("getANode");
-        //QVERIFY2(result.toString().toAscii() == "a", "ERROR: node cannot be retrieved.");
-
-   }
-
-   void TestDataStructure::testKrossRb(){
-   //   QFAIL("Ruby crashes the app");
-   //   createPentagon();
-   //
-   //   QVariantList graphLists;
-   //   graphLists.append( QVariant::fromValue( _graphDocument->at(0) ) );
-   //
-   //   KrossBackend *k = new KrossBackend(&graphLists);
-   //   k->setBackend("ruby");
-   //   k->loadFile("krossrbtests.rb");
-   //
-   //   // Kross::Action *action = k->execute();
-   //   // QVariant result = action->callFunction("getGraphName");
-   //   // qDebug()  << "Result" << result.toString().toAscii();
-   //
-   }*/
-
-// void TestDataStructure::testQtScript() {
-//     createPentagon();
-//
-//     QCOMPARE (_graphDocument->dataStructures().count(), 1);
-//
-//     QFAIL("#########    Need to reimplemt this test case! ########");
-
-// /*    QtScriptBackend *engine = _graphDocument->engineBackend();
-// //     engine->setDocument(&_graphDocument);
-// //     _graphDocument->setEngineBackend(engine);
-//
-//     engine->setScript(QString("graphs.length"), &_graphDocument);
-//     //QScriptValue results =
-//     engine->start();*/
-//     QVERIFY2(results.toNumber() == 1, "Error: number of graphs is not 1.");
-//
-//     results = engine->engine()->evaluate("graphs[0].list_datums().length");
-//     QVERIFY2(results.toNumber()  == 5, "Error: number of datums is not 5");
-//
-//     results = engine->engine()->evaluate("graphs[0].list_pointers().length");
-//     QVERIFY2(results.toNumber()  == 5, "Error: number of pointers is not 5");
-//
-//     QString script = "";
-//     script += "var graph = graphs[0]; \n ";
-//     script += "var node1 = graph.list_data()[0]; \n ";
-//     script += "var node2 = graph.list_data()[1]; \n ";
-//     script += "node1 != node2";
-//     results = engine->engine()->evaluate(script);
-//     QVERIFY2(results.toBoolean() == true, "ERROR: data are equal but they shouldn't be.");
-//
-//     script.clear();
-//     script += "var graph = graphs[0]; \n ";
-//     script += "var node1 = graph.list_data()[0]; \n ";
-//     script += "var node2 = graph.list_data()[1]; \n ";
-//     script += "node1.adj_edges().length";
-//     results = engine->engine()->evaluate(script);
-//     QVERIFY2( results.toNumber() == 2, results.toString().toAscii());
-// }
 
 QTEST_KDEMAIN_CORE(TestDataStructure)
